Changes
-------


pymills 3.4.1 (2014-09-16)
..........................

- Fixed a minor bug with ``pymills.utils.getFiles()``


pymills 3.4 (2013-11-20)
........................

- Initial Public Release

.. note:: No previous chagne log was kept.
